@@ -70,6 +70,7 @@
 
 #include "builtins.h"
 #include "einfo.h"
+#include "queue.h"
 #include "rc.h"
 #include "rc-misc.h"
 
@@ -282,7 +283,7 @@ fstabinfo(int argc, char **argv)
 		END_ENT;
 
 		if (!TAILQ_FIRST(files))
-			eerrorx("%s: emtpy fstab", argv[0]);
+			eerrorx("%s: empty fstab", argv[0]);
 	}
 
 	if (!TAILQ_FIRST(files)) {
@@ -298,6 +299,17 @@ fstabinfo(int argc, char **argv)
 			continue;
 		}
 
+		/* mount or remount? */
+		switch (output) {
+		case OUTPUT_MOUNT:
+			result += do_mount(ent, false);
+			break;
+
+		case OUTPUT_REMOUNT:
+			result += do_mount(ent, true);
+			break;
+		}
+
 		/* No point in outputting if quiet */
 		if (rc_yesno(getenv("EINFO_QUIET")))
 			continue;
@@ -307,14 +319,6 @@ fstabinfo(int argc, char **argv)
 			printf("%s\n", ENT_BLOCKDEVICE(ent));
 			break;
 
-		case OUTPUT_MOUNT:
-			result += do_mount(ent, false);
-			break;
-
-		case OUTPUT_REMOUNT:
-			result += do_mount(ent, true);
-			break;
-
 		case OUTPUT_MOUNTARGS:
 			printf("-o %s -t %s %s %s\n",
 			    ENT_OPTS(ent),
